@@ -108,7 +108,8 @@ mapPlot <- function(x,
                    panel.grid.minor = ggplot2::element_blank(),
                    ## Empty space left represents water areas. Color blue.
                    panel.background =
-                     ggplot2::element_rect(fill = "steelblue2")) +
+                     ggplot2::element_rect(fill = "steelblue2"),
+                   legend.key = ggplot2::element_rect(fill = "white")) +
     ggplot2::ggtitle(title)
   if (!isFALSE(printTrialNames)) {
     p <- p +
